﻿Anritsu Company                                             MET/CAL Procedure
=============================================================================
INSTRUMENT:            Sub MG369XB (2 yr) Power Level & Log /ML2437
DATE:                  2009-11-09 09:39:09
AUTHOR:                Fluke
REVISION:              $Revision: 2619 $
ADJUSTMENT THRESHOLD:  70%
NUMBER OF TESTS:       1
NUMBER OF LINES:       470
CONFIGURATION:         Anritsu ML2437A
=============================================================================
#
#  Procedure Author:
#        DAC
#
#  Model(s) Covered:
#        MG369XB w/o Option 2
#
#  Compatibility:
#        MET/CAL 7.20E or later
#
#  Subprocedures:
#        Sub MG369XB Init Power Level & Log RSLT Flags
#        Sub MG369XB Init Connection Flags
#        Sub MG369XB Reset & SRQ Masks
#        Sub MG369XB (2 yr) Pwr Lvl Log VER /ML2437
#        Sub MG369XB (2 yr) Pwr Lvl Tests >19 dBm /ML2437
#        Sub MG369XB (2 yr) Pwr Lvl Tests <=19 dBm /ML2437
#        Sub MG369XB Set Max Power
#
#  Required Files:
#        None
#
#  Additional Equipment Required:
#        None
#
#  The copyright for this procedure is owned by Fluke Corporation.
#
 STEP    FSC    RANGE NOMINAL        TOLERANCE     MOD1        MOD2  3  4 CON

  1.001  CALL         Sub MG369XB Init Power Level & Log RSLT Flags
  1.002  MATH         @ML2430A_Ch = "A"; @Iteration = 1; Done = 0

# This loop is to minimize connection changes during power level tests.
#
# Tests above +19 dBm must use a 10 dB attenuator to prevent damage to the
# power meter and/or power sensor.
#
# Iteration 1:  Perform all tests using the ML2430A with an attenuator.
# Iteration 2:  Perform all tests using the ML2430A w/o an attenuator.
#
# Note, within each Iteration, a power sensor change or installation of the
# mixer will be required when frequency exceeds a specified value.
  1.003  DO

  1.004  IF           NOT(@RsltLogConformity)
  1.005  RSLT         =
  1.006  RSLT         =POWER LEVEL LOG CONFORMITY TESTS
  1.007  MATH         @RsltLogConformity = 1
  1.008  ENDIF

  1.009  IF           NOT(@RsltPulseModOff) && @Opt_13
  1.010  RSLT         =
  1.011  RSLT         = External Pulse Modulation Off
  1.012  MATH         @RsltPulseModOff = 1
  1.013  ENDIF

  1.014  HEAD         POWER LEVEL LOG CONFORMITY
  1.015  TARGET       -p
  1.016  CALL         Sub MG369XB Reset & SRQ Masks
  1.017  MATH         @RsltLogFreq1 = @RsltLogFreq1NoPulse
  1.018  MATH         @RsltLogFreq2 = @RsltLogFreq2NoPulse
  1.019  CALL         Sub MG369XB (2 yr) Pwr Lvl Log VER /ML2437
  1.020  MATH         @RsltLogFreq1NoPulse = @RsltLogFreq1
  1.021  MATH         @RsltLogFreq2NoPulse = @RsltLogFreq2

# For models with pulse modulation, repeat the Log Conformity tests with
# external pulse mode selected.
  1.022  IF           @Opt_13 || @Opt_24
  1.023  HEAD         POWER LEVEL LOG CONFORMITY w/EXTERNAL PULSE ON

  1.024  IF           NOT(@RsltPulseModOn)
  1.025  RSLT         =
  1.026  RSLT         = External Pulse Modulation On
  1.027  MATH         @RsltPulseModOn = 1
  1.028  ENDIF

  1.029  TARGET       -p
  1.030  CALL         Sub MG369XB Reset & SRQ Masks
  1.031  IEEE         XP
  1.032  MATH         @RsltLogFreq1 = @RsltLogFreq1Pulse
  1.033  MATH         @RsltLogFreq2 = @RsltLogFreq2Pulse
  1.034  CALL         Sub MG369XB (2 yr) Pwr Lvl Log VER /ML2437
  1.035  MATH         @RsltLogFreq1Pulse = @RsltLogFreq1
  1.036  MATH         @RsltLogFreq2Pulse = @RsltLogFreq2
  1.037  ENDIF

  1.038  IF           NOT(@RsltPwrLvlAcc)
  1.039  RSLT         =
  1.040  RSLT         =POWER LEVEL ACCURACY TESTS
  1.041  MATH         @RsltPwrLvlAcc = 1
  1.042  ENDIF

  1.043  HEAD         POWER LEVEL ACCURACY
  1.044  TARGET       -p
  1.045  CALL         Sub MG369XB Reset & SRQ Masks

# 10 MHz
  1.046  IF           @Opt_4 || @Opt_5
  1.047  MATH         @FreqGHz = "0.01"; @RsltFreq = @RsltLvlFreq_10MHz
  1.048  CALL         Sub MG369XB Set Max Power

  1.049  IF           (@Iteration == 1) && (@MaxPower > +19)
  1.050  CALL         Sub MG369XB (2 yr) Pwr Lvl Tests >19 dBm /ML2437
  1.051  ELSEIF       (@Iteration == 2)
  1.052  CALL         Sub MG369XB (2 yr) Pwr Lvl Tests <=19 dBm /ML2437
  1.053  ENDIF

  1.054  MATH         @RsltLvlFreq_10MHz = @RsltFreq

# 15 MHz
  1.055  MATH         @FreqGHz = "0.015"; @RsltFreq = @RsltLvlFreq_15MHz
  1.056  CALL         Sub MG369XB Set Max Power

  1.057  IF           (@Iteration == 1) && (@MaxPower > +19)
  1.058  CALL         Sub MG369XB (2 yr) Pwr Lvl Tests >19 dBm /ML2437
  1.059  ELSEIF       (@Iteration == 2)
  1.060  CALL         Sub MG369XB (2 yr) Pwr Lvl Tests <=19 dBm /ML2437
  1.061  ENDIF

  1.062  MATH         @RsltLvlFreq_15MHz = @RsltFreq

# 60 MHz
  1.063  MATH         @FreqGHz = "0.06"; @RsltFreq = @RsltLvlFreq_60MHz
  1.064  CALL         Sub MG369XB Set Max Power

  1.065  IF           (@Iteration == 1) && (@MaxPower > +19)
  1.066  CALL         Sub MG369XB (2 yr) Pwr Lvl Tests >19 dBm /ML2437
  1.067  ELSEIF       (@Iteration == 2)
  1.068  CALL         Sub MG369XB (2 yr) Pwr Lvl Tests <=19 dBm /ML2437
  1.069  ENDIF

  1.070  MATH         @RsltLvlFreq_60MHz = @RsltFreq

# 500 MHz
  1.071  MATH         @FreqGHz = "0.50"; @RsltFreq = @RsltLvlFreq_500MHz
  1.072  CALL         Sub MG369XB Set Max Power

  1.073  IF           (@Iteration == 1) && (@MaxPower > +19)
  1.074  CALL         Sub MG369XB (2 yr) Pwr Lvl Tests >19 dBm /ML2437
  1.075  ELSEIF       (@Iteration == 2)
  1.076  CALL         Sub MG369XB (2 yr) Pwr Lvl Tests <=19 dBm /ML2437
  1.077  ENDIF

  1.078  MATH         @RsltLvlFreq_500MHz = @RsltFreq

# 600 MHz
  1.079  MATH         @FreqGHz = "0.60"; @RsltFreq = @RsltLvlFreq_600MHz
  1.080  CALL         Sub MG369XB Set Max Power

  1.081  IF           (@Iteration == 1) && (@MaxPower > +19)
  1.082  CALL         Sub MG369XB (2 yr) Pwr Lvl Tests >19 dBm /ML2437
  1.083  ELSEIF       (@Iteration == 2)
  1.084  CALL         Sub MG369XB (2 yr) Pwr Lvl Tests <=19 dBm /ML2437
  1.085  ENDIF

  1.086  MATH         @RsltLvlFreq_600MHz = @RsltFreq
  1.087  ENDIF        ; @Opt_4 || @Opt_5

# 2 GHz
  1.088  MATH         @FreqGHz = "2.00"; @RsltFreq = @RsltLvlFreq_2GHz
  1.089  CALL         Sub MG369XB Set Max Power

  1.090  IF           (@Iteration == 1) && (@MaxPower > +19)
  1.091  CALL         Sub MG369XB (2 yr) Pwr Lvl Tests >19 dBm /ML2437
  1.092  ELSEIF       (@Iteration == 2)
  1.093  CALL         Sub MG369XB (2 yr) Pwr Lvl Tests <=19 dBm /ML2437
  1.094  ENDIF

  1.095  MATH         @RsltLvlFreq_2GHz = @RsltFreq

# 4 GHz
  1.096  MATH         @FreqGHz = "4.00"; @RsltFreq = @RsltLvlFreq_4GHz
  1.097  CALL         Sub MG369XB Set Max Power

  1.098  IF           (@Iteration == 1) && (@MaxPower > +19)
  1.099  CALL         Sub MG369XB (2 yr) Pwr Lvl Tests >19 dBm /ML2437
  1.100  ELSEIF       (@Iteration == 2)
  1.101  CALL         Sub MG369XB (2 yr) Pwr Lvl Tests <=19 dBm /ML2437
  1.102  ENDIF

  1.103  MATH         @RsltLvlFreq_4GHz = @RsltFreq

# 6 GHz
  1.104  MATH         @FreqGHz = "6.00"; @RsltFreq = @RsltLvlFreq_6GHz
  1.105  CALL         Sub MG369XB Set Max Power

  1.106  IF           (@Iteration == 1) && (@MaxPower > +19)
  1.107  CALL         Sub MG369XB (2 yr) Pwr Lvl Tests >19 dBm /ML2437
  1.108  ELSEIF       (@Iteration == 2)
  1.109  CALL         Sub MG369XB (2 yr) Pwr Lvl Tests <=19 dBm /ML2437
  1.110  ENDIF

  1.111  MATH         @RsltLvlFreq_6GHz = @RsltFreq

# 8 GHz
  1.112  MATH         @FreqGHz = "8.00"; @RsltFreq = @RsltLvlFreq_8GHz
  1.113  CALL         Sub MG369XB Set Max Power

  1.114  IF           (@Iteration == 1) && (@MaxPower > +19)
  1.115  CALL         Sub MG369XB (2 yr) Pwr Lvl Tests >19 dBm /ML2437
  1.116  ELSEIF       (@Iteration == 2)
  1.117  CALL         Sub MG369XB (2 yr) Pwr Lvl Tests <=19 dBm /ML2437
  1.118  ENDIF

  1.119  MATH         @RsltLvlFreq_8GHz = @RsltFreq

# 10 GHz
  1.120  MATH         @FreqGHz = "10.0"; @RsltFreq = @RsltLvlFreq_10GHz
  1.121  CALL         Sub MG369XB Set Max Power

  1.122  IF           (@Iteration == 1) && (@MaxPower > +19)
  1.123  CALL         Sub MG369XB (2 yr) Pwr Lvl Tests >19 dBm /ML2437
  1.124  ELSEIF       (@Iteration == 2)
  1.125  CALL         Sub MG369XB (2 yr) Pwr Lvl Tests <=19 dBm /ML2437
  1.126  ENDIF

  1.127  MATH         @RsltLvlFreq_10GHz = @RsltFreq

  1.128  IF           @MaxFreq > 10E+9

# 12 GHz
  1.129  MATH         @FreqGHz = "12.0"; @RsltFreq = @RsltLvlFreq_12GHz
  1.130  CALL         Sub MG369XB Set Max Power

  1.131  IF           (@Iteration == 1) && (@MaxPower > +19)
  1.132  CALL         Sub MG369XB (2 yr) Pwr Lvl Tests >19 dBm /ML2437
  1.133  ELSEIF       (@Iteration == 2)
  1.134  CALL         Sub MG369XB (2 yr) Pwr Lvl Tests <=19 dBm /ML2437
  1.135  ENDIF

  1.136  MATH         @RsltLvlFreq_12GHz = @RsltFreq

# 14 GHz
  1.137  MATH         @FreqGHz = "14.0"; @RsltFreq = @RsltLvlFreq_14GHz
  1.138  CALL         Sub MG369XB Set Max Power

  1.139  IF           (@Iteration == 1) && (@MaxPower > +19)
  1.140  CALL         Sub MG369XB (2 yr) Pwr Lvl Tests >19 dBm /ML2437
  1.141  ELSEIF       (@Iteration == 2)
  1.142  CALL         Sub MG369XB (2 yr) Pwr Lvl Tests <=19 dBm /ML2437
  1.143  ENDIF

  1.144  MATH         @RsltLvlFreq_14GHz = @RsltFreq

# 16 GHz
  1.145  MATH         @FreqGHz = "16.0"; @RsltFreq = @RsltLvlFreq_16GHz
  1.146  CALL         Sub MG369XB Set Max Power

  1.147  IF           (@Iteration == 1) && (@MaxPower > +19)
  1.148  CALL         Sub MG369XB (2 yr) Pwr Lvl Tests >19 dBm /ML2437
  1.149  ELSEIF       (@Iteration == 2)
  1.150  CALL         Sub MG369XB (2 yr) Pwr Lvl Tests <=19 dBm /ML2437
  1.151  ENDIF

  1.152  MATH         @RsltLvlFreq_16GHz = @RsltFreq

# 18 GHz
  1.153  MATH         @FreqGHz = "18.0"; @RsltFreq = @RsltLvlFreq_18GHz
  1.154  CALL         Sub MG369XB Set Max Power

  1.155  IF           (@Iteration == 1) && (@MaxPower > +19)
  1.156  CALL         Sub MG369XB (2 yr) Pwr Lvl Tests >19 dBm /ML2437
  1.157  ELSEIF       (@Iteration == 2)
  1.158  CALL         Sub MG369XB (2 yr) Pwr Lvl Tests <=19 dBm /ML2437
  1.159  ENDIF

  1.160  MATH         @RsltLvlFreq_18GHz = @RsltFreq

# 20 GHz
  1.161  MATH         @FreqGHz = "20.0"; @RsltFreq = @RsltLvlFreq_20GHz
  1.162  CALL         Sub MG369XB Set Max Power

  1.163  IF           (@Iteration == 1) && (@MaxPower > +19)
  1.164  CALL         Sub MG369XB (2 yr) Pwr Lvl Tests >19 dBm /ML2437
  1.165  ELSEIF       (@Iteration == 2)
  1.166  CALL         Sub MG369XB (2 yr) Pwr Lvl Tests <=19 dBm /ML2437
  1.167  ENDIF

  1.168  MATH         @RsltLvlFreq_20GHz = @RsltFreq

  1.169  IF           ; @MaxFreq > 20E+9

# 22 GHz
  1.170  MATH         @FreqGHz = "22.0"; @RsltFreq = @RsltLvlFreq_22GHz
  1.171  CALL         Sub MG369XB Set Max Power

  1.172  IF           (@Iteration == 1) && (@MaxPower > +19)
  1.173  CALL         Sub MG369XB (2 yr) Pwr Lvl Tests >19 dBm /ML2437
  1.174  ELSEIF       (@Iteration == 2)
  1.175  CALL         Sub MG369XB (2 yr) Pwr Lvl Tests <=19 dBm /ML2437
  1.176  ENDIF

  1.177  MATH         @RsltLvlFreq_22GHz = @RsltFreq

# 24 GHz
  1.178  MATH         @FreqGHz = "24.0"; @RsltFreq = @RsltLvlFreq_24GHz
  1.179  CALL         Sub MG369XB Set Max Power

  1.180  IF           (@Iteration == 1) && (@MaxPower > +19)
  1.181  CALL         Sub MG369XB (2 yr) Pwr Lvl Tests >19 dBm /ML2437
  1.182  ELSEIF       (@Iteration == 2)
  1.183  CALL         Sub MG369XB (2 yr) Pwr Lvl Tests <=19 dBm /ML2437
  1.184  ENDIF

  1.185  MATH         @RsltLvlFreq_24GHz = @RsltFreq

# 26 GHz
  1.186  MATH         @FreqGHz = "26.0"; @RsltFreq = @RsltLvlFreq_26GHz
  1.187  CALL         Sub MG369XB Set Max Power

  1.188  IF           (@Iteration == 1) && (@MaxPower > +19)
  1.189  CALL         Sub MG369XB (2 yr) Pwr Lvl Tests >19 dBm /ML2437
  1.190  ELSEIF       (@Iteration == 2)
  1.191  CALL         Sub MG369XB (2 yr) Pwr Lvl Tests <=19 dBm /ML2437
  1.192  ENDIF

  1.193  MATH         @RsltLvlFreq_26GHz = @RsltFreq

# 28 GHz
  1.194  MATH         @FreqGHz = "28.0"; @RsltFreq = @RsltLvlFreq_28GHz
  1.195  CALL         Sub MG369XB Set Max Power

  1.196  IF           (@Iteration == 1) && (@MaxPower > +19)
  1.197  CALL         Sub MG369XB (2 yr) Pwr Lvl Tests >19 dBm /ML2437
  1.198  ELSEIF       (@Iteration == 2)
  1.199  CALL         Sub MG369XB (2 yr) Pwr Lvl Tests <=19 dBm /ML2437
  1.200  ENDIF

  1.201  MATH         @RsltLvlFreq_28GHz = @RsltFreq

# 30 GHz
  1.202  MATH         @FreqGHz = "30.0"; @RsltFreq = @RsltLvlFreq_30GHz
  1.203  CALL         Sub MG369XB Set Max Power

  1.204  IF           (@Iteration == 1) && (@MaxPower > +19)
  1.205  CALL         Sub MG369XB (2 yr) Pwr Lvl Tests >19 dBm /ML2437
  1.206  ELSEIF       (@Iteration == 2)
  1.207  CALL         Sub MG369XB (2 yr) Pwr Lvl Tests <=19 dBm /ML2437
  1.208  ENDIF

  1.209  MATH         @RsltLvlFreq_30GHz = @RsltFreq

  1.210  IF           @MaxFreq > 30E+9

# 32 GHz
  1.211  MATH         @FreqGHz = "32.0"; @RsltFreq = @RsltLvlFreq_32GHz
  1.212  CALL         Sub MG369XB Set Max Power

  1.213  IF           (@Iteration == 1) && (@MaxPower > +19)
  1.214  CALL         Sub MG369XB (2 yr) Pwr Lvl Tests >19 dBm /ML2437
  1.215  ELSEIF       (@Iteration == 2)
  1.216  CALL         Sub MG369XB (2 yr) Pwr Lvl Tests <=19 dBm /ML2437
  1.217  ENDIF

  1.218  MATH         @RsltLvlFreq_32GHz = @RsltFreq

# 34 GHz
  1.219  MATH         @FreqGHz = "34.0"; @RsltFreq = @RsltLvlFreq_34GHz
  1.220  CALL         Sub MG369XB Set Max Power

  1.221  IF           (@Iteration == 1) && (@MaxPower > +19)
  1.222  CALL         Sub MG369XB (2 yr) Pwr Lvl Tests >19 dBm /ML2437
  1.223  ELSEIF       (@Iteration == 2)
  1.224  CALL         Sub MG369XB (2 yr) Pwr Lvl Tests <=19 dBm /ML2437
  1.225  ENDIF

  1.226  MATH         @RsltLvlFreq_34GHz = @RsltFreq

# 36 GHz
  1.227  MATH         @FreqGHz = "36.0"; @RsltFreq = @RsltLvlFreq_36GHz
  1.228  CALL         Sub MG369XB Set Max Power

  1.229  IF           (@Iteration == 1) && (@MaxPower > +19)
  1.230  CALL         Sub MG369XB (2 yr) Pwr Lvl Tests >19 dBm /ML2437
  1.231  ELSEIF       (@Iteration == 2)
  1.232  CALL         Sub MG369XB (2 yr) Pwr Lvl Tests <=19 dBm /ML2437
  1.233  ENDIF

  1.234  MATH         @RsltLvlFreq_36GHz = @RsltFreq

# 38 GHz
  1.235  MATH         @FreqGHz = "38.0"; @RsltFreq = @RsltLvlFreq_38GHz
  1.236  CALL         Sub MG369XB Set Max Power

  1.237  IF           (@Iteration == 1) && (@MaxPower > +19)
  1.238  CALL         Sub MG369XB (2 yr) Pwr Lvl Tests >19 dBm /ML2437
  1.239  ELSEIF       (@Iteration == 2)
  1.240  CALL         Sub MG369XB (2 yr) Pwr Lvl Tests <=19 dBm /ML2437
  1.241  ENDIF

  1.242  MATH         @RsltLvlFreq_38GHz = @RsltFreq

# 40 GHz
  1.243  MATH         @FreqGHz = "40.0"; @RsltFreq = @RsltLvlFreq_40GHz
  1.244  CALL         Sub MG369XB Set Max Power

  1.245  IF           (@Iteration == 1) && (@MaxPower > +19)
  1.246  CALL         Sub MG369XB (2 yr) Pwr Lvl Tests >19 dBm /ML2437
  1.247  ELSEIF       (@Iteration == 2)
  1.248  CALL         Sub MG369XB (2 yr) Pwr Lvl Tests <=19 dBm /ML2437
  1.249  ENDIF

  1.250  MATH         @RsltLvlFreq_40GHz = @RsltFreq

# Note, 50, 60, & 67 GHz are not tested at > +19 dBm or < -60 dBm.
  1.251  IF           @MaxFreq > 40E+9

# 50 GHz
  1.252  MATH         @FreqGHz = "50.0"
  1.253  CALL         Sub MG369XB Set Max Power

  1.254  IF           (@Iteration == 2)
  1.255  MATH         @RsltFreq = 0
  1.256  CALL         Sub MG369XB (2 yr) Pwr Lvl Tests <=19 dBm /ML2437
  1.257  ENDIF

  1.258  MATH         @RsltLvlFreq_50GHz = @RsltFreq

  1.259  IF           @MaxFreq > 50E+9

# 60 GHz
  1.260  MATH         @FreqGHz = "60.0"
  1.261  CALL         Sub MG369XB Set Max Power

  1.262  IF           (@Iteration == 2)
  1.263  MATH         @RsltFreq = 0
  1.264  CALL         Sub MG369XB (2 yr) Pwr Lvl Tests <=19 dBm /ML2437
  1.265  ENDIF

# 65 GHz or 67 GHz
  1.266  MATH         @FreqGHz = @MaxFreq / 1.0E+9
  1.267  CALL         Sub MG369XB Set Max Power

  1.268  IF           (@Iteration == 2)
  1.269  MATH         @RsltFreq = 0
  1.270  CALL         Sub MG369XB (2 yr) Pwr Lvl Tests <=19 dBm /ML2437
  1.271  ENDIF

  1.272  ENDIF        ; @MaxFreq > 50E+9

  1.273  ENDIF        ; @MaxFreq > 40E+9

  1.274  ENDIF        ; @MaxFreq > 30E+9

  1.275  ENDIF        ; @MaxFreq > 20E+9

  1.276  ENDIF        ; @MaxFreq > 10E+9

  1.277  MATH         @Iteration = @Iteration + 1
  1.278  UNTIL        @Iteration > 2

  1.279  HEAD
  1.280  CALL         Sub MG369XB Reset & SRQ Masks
  1.281  ML2437       Reset
  1.282  END
