﻿© 2010 Fluke Corporation, All rights reserved               MET/CAL Procedure
=============================================================================
INSTRUMENT:            Sub MG369XB (2 yr) Power Level & Log /ML2437,ML2530,LO
DATE:                  2010-02-10 07:22:45
AUTHOR:                Fluke
REVISION:              $Revision: 2619 $
ADJUSTMENT THRESHOLD:  70%
NUMBER OF TESTS:       1
NUMBER OF LINES:       639
CONFIGURATION:         Anritsu ML2530A
CONFIGURATION:         Anritsu ML2437A
CONFIGURATION:         Local Oscillator
=============================================================================
#
#  Procedure Author:
#        DAC
#
#  Model(s) Covered:
#        MG369XB
#
#  Compatibility:
#        MET/CAL 7.20E or later
#
#  Subprocedures:
#        Sub MG369XB Init Power Level & Log RSLT Flags
#        Sub MG369XB Init Power Level Accuracy Variables
#        Sub MG369XB Reset & SRQ Masks
#        Sub MG369XB (2 yr) Pwr Lvl Log VER /ML2437
#        Sub MG369XB (2 yr) Pwr Lvl Tests >19 dBm /ML2437
#        Sub MG369XB (2 yr) Pwr Lvl Tests <=19 dBm Opt 2 /ML2437
#        Sub MG369XB (2 yr) Pwr Level Tests /ML2530
#        Sub MG369XB (2 yr) Pwr Level Tests /ML2530,LO
#        Sub MG369XB Set Max Power
#
#  Required Files:
#        None
#
#  Additional Equipment Required:
#        None
#
#  The copyright for this procedure is owned by Fluke Corporation.
#
 STEP    FSC    RANGE NOMINAL        TOLERANCE     MOD1        MOD2  3  4 CON

# Dummy statements to force header to contain reference used in subprocedure.
  1.001  IF           0
  1.002  IEEE         [@LO]
  1.003  ENDIF

  1.004  CALL         Sub MG369XB Init Power Level & Log RSLT Flags
  1.005  CALL         Sub MG369XB Init Power Level Accuracy Variables

# Initialize flag to designate if Range Cal has been performed for tests
# which use the mixer.
  1.006  MATH         @ML2530_LO_RangeCal = 0
  1.007  MATH         @ML2430A_Ch = "A"; @Iteration = 1; Done = 0

# This loop is to minimize connection changes during power level tests.
#
# Tests above +19 dBm must use a 10 dB attenuator to prevent damage to the
# power meter and/or power sensor.
#
# Iteration 1:  Perform all tests using the ML2430A with an attenuator.
# Iteration 2:  Perform all tests using the ML2430A w/o an attenuator.
# Iteration 3:  Perform all tests using the ML2530A
#
# Note, within each Iteration, a power sensor change or installation of the
# mixer will be required when frequency exceeds a specified value.
  1.008  DO

  1.009  IF           NOT(@RsltLogConformity)
  1.010  RSLT         =
  1.011  RSLT         =POWER LEVEL LOG CONFORMITY TESTS
  1.012  MATH         @RsltLogConformity = 1
  1.013  ENDIF

  1.014  IF           NOT(@RsltPulseModOff) && @Opt_13
  1.015  RSLT         =
  1.016  RSLT         = External Pulse Modulation Off
  1.017  MATH         @RsltPulseModOff = 1
  1.018  ENDIF

  1.019  HEAD         POWER LEVEL LOG CONFORMITY
  1.020  TARGET       -p
  1.021  CALL         Sub MG369XB Reset & SRQ Masks
  1.022  MATH         @RsltLogFreq1 = @RsltLogFreq1NoPulse
  1.023  MATH         @RsltLogFreq2 = @RsltLogFreq2NoPulse
  1.024  CALL         Sub MG369XB (2 yr) Pwr Lvl Log VER /ML2437
  1.025  MATH         @RsltLogFreq1NoPulse = @RsltLogFreq1
  1.026  MATH         @RsltLogFreq2NoPulse = @RsltLogFreq2

# For models with pulse modulation, repeat the Log Conformity tests with
# external pulse mode selected.
  1.027  IF           @Opt_13 || @Opt_24
  1.028  HEAD         POWER LEVEL LOG CONFORMITY w/EXTERNAL PULSE ON

  1.029  IF           NOT(@RsltPulseModOn)
  1.030  RSLT         =
  1.031  RSLT         = External Pulse Modulation On
  1.032  MATH         @RsltPulseModOn = 1
  1.033  ENDIF

  1.034  TARGET       -p
  1.035  CALL         Sub MG369XB Reset & SRQ Masks
  1.036  IEEE         XP
  1.037  MATH         @RsltLogFreq1 = @RsltLogFreq1Pulse
  1.038  MATH         @RsltLogFreq2 = @RsltLogFreq2Pulse
  1.039  CALL         Sub MG369XB (2 yr) Pwr Lvl Log VER /ML2437
  1.040  MATH         @RsltLogFreq1Pulse = @RsltLogFreq1
  1.041  MATH         @RsltLogFreq2Pulse = @RsltLogFreq2
  1.042  ENDIF

  1.043  IF           NOT(@RsltPwrLvlAcc)
  1.044  RSLT         =
  1.045  RSLT         =POWER LEVEL ACCURACY TESTS
  1.046  MATH         @RsltPwrLvlAcc = 1
  1.047  ENDIF

  1.048  HEAD         POWER LEVEL ACCURACY
  1.049  TARGET       -p
  1.050  CALL         Sub MG369XB Reset & SRQ Masks

  1.051  IF           @Opt_4 || @Opt_5

# 10 MHz
  1.052  MATH         @FreqGHz = "0.01"; @RsltFreq = @RsltLvlFreq_10MHz
  1.053  CALL         Sub MG369XB Set Max Power

  1.054  IF           (@Iteration == 1) && (@MaxPower > +19)
  1.055  CALL         Sub MG369XB (2 yr) Pwr Lvl Tests >19 dBm /ML2437
  1.056  ELSEIF       (@Iteration == 2)
  1.057  CALL         Sub MG369XB (2 yr) Pwr Lvl Tests <=19 dBm Opt 2 /ML2437
  1.058  MATH         @ML2430A_AccWNeg20dBm10MHz = @ML2430A_AccWNeg20dBm
  1.059  MATH         @ML2430A_AccWNeg50dBm10MHz = @ML2430A_AccWNeg50dBm
  1.060  ELSEIF       (@Iteration == 3)
  1.061  CALL         Sub MG369XB (2 yr) Pwr Level Tests /ML2530
  1.062  ENDIF

  1.063  MATH         @RsltLvlFreq_10MHz = @RsltFreq

# 15 MHz
  1.064  MATH         @FreqGHz = "0.015"; @RsltFreq = @RsltLvlFreq_15MHz
  1.065  CALL         Sub MG369XB Set Max Power

  1.066  IF           (@Iteration == 1) && (@MaxPower > +19)
  1.067  CALL         Sub MG369XB (2 yr) Pwr Lvl Tests >19 dBm /ML2437
  1.068  ELSEIF       (@Iteration == 2)
  1.069  CALL         Sub MG369XB (2 yr) Pwr Lvl Tests <=19 dBm Opt 2 /ML2437
  1.070  MATH         @ML2430A_AccWNeg20dBm15MHz = @ML2430A_AccWNeg20dBm
  1.071  MATH         @ML2430A_AccWNeg50dBm15MHz = @ML2430A_AccWNeg50dBm
  1.072  ELSEIF       (@Iteration == 3)
  1.073  CALL         Sub MG369XB (2 yr) Pwr Level Tests /ML2530
  1.074  ENDIF

  1.075  MATH         @RsltLvlFreq_15MHz = @RsltFreq

# 60 MHz
  1.076  MATH         @FreqGHz = "0.06"; @RsltFreq = @RsltLvlFreq_60MHz
  1.077  CALL         Sub MG369XB Set Max Power

  1.078  IF           (@Iteration == 1) && (@MaxPower > +19)
  1.079  CALL         Sub MG369XB (2 yr) Pwr Lvl Tests >19 dBm /ML2437
  1.080  ELSEIF       (@Iteration == 2)
  1.081  CALL         Sub MG369XB (2 yr) Pwr Lvl Tests <=19 dBm Opt 2 /ML2437
  1.082  MATH         @ML2430A_AccWNeg20dBm60MHz = @ML2430A_AccWNeg20dBm
  1.083  MATH         @ML2430A_AccWNeg50dBm60MHz = @ML2430A_AccWNeg50dBm
  1.084  ELSEIF       (@Iteration == 3)
  1.085  CALL         Sub MG369XB (2 yr) Pwr Level Tests /ML2530
  1.086  ENDIF

  1.087  MATH         @RsltLvlFreq_60MHz = @RsltFreq

# 500 MHz
  1.088  MATH         @FreqGHz = "0.50"; @RsltFreq = @RsltLvlFreq_500MHz
  1.089  CALL         Sub MG369XB Set Max Power

  1.090  IF           (@Iteration == 1) && (@MaxPower > +19)
  1.091  CALL         Sub MG369XB (2 yr) Pwr Lvl Tests >19 dBm /ML2437
  1.092  ELSEIF       (@Iteration == 2)
  1.093  CALL         Sub MG369XB (2 yr) Pwr Lvl Tests <=19 dBm Opt 2 /ML2437
  1.094  MATH         @ML2430A_AccWNeg20dBm500MHz = @ML2430A_AccWNeg20dBm
  1.095  MATH         @ML2430A_AccWNeg50dBm500MHz = @ML2430A_AccWNeg50dBm
  1.096  ELSEIF       (@Iteration == 3)
  1.097  CALL         Sub MG369XB (2 yr) Pwr Level Tests /ML2530
  1.098  ENDIF

  1.099  MATH         @RsltLvlFreq_500MHz = @RsltFreq

# 600 MHz
  1.100  MATH         @FreqGHz = "0.60"; @RsltFreq = @RsltLvlFreq_600MHz
  1.101  CALL         Sub MG369XB Set Max Power

  1.102  IF           (@Iteration == 1) && (@MaxPower > +19)
  1.103  CALL         Sub MG369XB (2 yr) Pwr Lvl Tests >19 dBm /ML2437
  1.104  ELSEIF       (@Iteration == 2)
  1.105  CALL         Sub MG369XB (2 yr) Pwr Lvl Tests <=19 dBm Opt 2 /ML2437
  1.106  MATH         @ML2430A_AccWNeg20dBm600MHz = @ML2430A_AccWNeg20dBm
  1.107  MATH         @ML2430A_AccWNeg50dBm600MHz = @ML2430A_AccWNeg50dBm
  1.108  ELSEIF       (@Iteration == 3)
  1.109  CALL         Sub MG369XB (2 yr) Pwr Level Tests /ML2530
  1.110  ENDIF

  1.111  MATH         @RsltLvlFreq_600MHz = @RsltFreq

# 1 GHz
  1.112  MATH         @FreqGHz = "1.00"; @RsltFreq = @RsltLvlFreq_1GHz
  1.113  CALL         Sub MG369XB Set Max Power

  1.114  IF           (@Iteration == 1) && (@MaxPower > +19)
  1.115  CALL         Sub MG369XB (2 yr) Pwr Lvl Tests >19 dBm /ML2437
  1.116  ELSEIF       (@Iteration == 2)
  1.117  CALL         Sub MG369XB (2 yr) Pwr Lvl Tests <=19 dBm Opt 2 /ML2437
  1.118  MATH         @ML2430A_AccWNeg20dBm1GHz = @ML2430A_AccWNeg20dBm
  1.119  MATH         @ML2430A_AccWNeg50dBm1GHz = @ML2430A_AccWNeg50dBm
  1.120  ELSEIF       (@Iteration == 3)
  1.121  CALL         Sub MG369XB (2 yr) Pwr Level Tests /ML2530
  1.122  ENDIF

  1.123  MATH         @RsltLvlFreq_1GHz = @RsltFreq
  1.124  ENDIF        ; @Opt_4 || @Opt_5

# 2 GHz
  1.125  MATH         @FreqGHz = "2.00"; @RsltFreq = @RsltLvlFreq_2GHz
  1.126  CALL         Sub MG369XB Set Max Power

  1.127  IF           (@Iteration == 1) && (@MaxPower > +19)
  1.128  CALL         Sub MG369XB (2 yr) Pwr Lvl Tests >19 dBm /ML2437
  1.129  ELSEIF       (@Iteration == 2)
  1.130  CALL         Sub MG369XB (2 yr) Pwr Lvl Tests <=19 dBm Opt 2 /ML2437
  1.131  MATH         @ML2430A_AccWNeg20dBm2GHz = @ML2430A_AccWNeg20dBm
  1.132  MATH         @ML2430A_AccWNeg50dBm2GHz = @ML2430A_AccWNeg50dBm
  1.133  ELSEIF       (@Iteration == 3)
  1.134  CALL         Sub MG369XB (2 yr) Pwr Level Tests /ML2530
  1.135  ENDIF

  1.136  MATH         @RsltLvlFreq_2GHz = @RsltFreq

# 4 GHz
  1.137  MATH         @FreqGHz = "4.00"; @RsltFreq = @RsltLvlFreq_4GHz
  1.138  CALL         Sub MG369XB Set Max Power

  1.139  IF           (@Iteration == 1) && (@MaxPower > +19)
  1.140  CALL         Sub MG369XB (2 yr) Pwr Lvl Tests >19 dBm /ML2437
  1.141  ELSEIF       (@Iteration == 2)
  1.142  CALL         Sub MG369XB (2 yr) Pwr Lvl Tests <=19 dBm Opt 2 /ML2437
  1.143  MATH         @ML2430A_AccWNeg20dBm4GHz = @ML2430A_AccWNeg20dBm
  1.144  MATH         @ML2430A_AccWNeg50dBm4GHz = @ML2430A_AccWNeg50dBm
  1.145  ELSEIF       (@Iteration == 3)
  1.146  MATH         @LoFreqMHz = 3991.49
  1.147  CALL         Sub MG369XB (2 yr) Pwr Level Tests /ML2530,LO
  1.148  ENDIF

  1.149  MATH         @RsltLvlFreq_4GHz = @RsltFreq

# 6 GHz
  1.150  MATH         @FreqGHz = "6.00"; @RsltFreq = @RsltLvlFreq_6GHz
  1.151  CALL         Sub MG369XB Set Max Power

  1.152  IF           (@Iteration == 1) && (@MaxPower > +19)
  1.153  CALL         Sub MG369XB (2 yr) Pwr Lvl Tests >19 dBm /ML2437
  1.154  ELSEIF       (@Iteration == 2)
  1.155  CALL         Sub MG369XB (2 yr) Pwr Lvl Tests <=19 dBm Opt 2 /ML2437
  1.156  MATH         @ML2430A_AccWNeg20dBm6GHz = @ML2430A_AccWNeg20dBm
  1.157  MATH         @ML2430A_AccWNeg50dBm6GHz = @ML2430A_AccWNeg50dBm
  1.158  ELSEIF       (@Iteration == 3)
  1.159  MATH         @LoFreqMHz = 5991.49
  1.160  CALL         Sub MG369XB (2 yr) Pwr Level Tests /ML2530,LO
  1.161  ENDIF

  1.162  MATH         @RsltLvlFreq_6GHz = @RsltFreq

# 8 GHz
  1.163  MATH         @FreqGHz = "8.00"; @RsltFreq = @RsltLvlFreq_8GHz
  1.164  CALL         Sub MG369XB Set Max Power

  1.165  IF           (@Iteration == 1) && (@MaxPower > +19)
  1.166  CALL         Sub MG369XB (2 yr) Pwr Lvl Tests >19 dBm /ML2437
  1.167  ELSEIF       (@Iteration == 2)
  1.168  CALL         Sub MG369XB (2 yr) Pwr Lvl Tests <=19 dBm Opt 2 /ML2437
  1.169  MATH         @ML2430A_AccWNeg20dBm8GHz = @ML2430A_AccWNeg20dBm
  1.170  MATH         @ML2430A_AccWNeg50dBm8GHz = @ML2430A_AccWNeg50dBm
  1.171  ELSEIF       (@Iteration == 3)
  1.172  MATH         @LoFreqMHz = 7991.49
  1.173  CALL         Sub MG369XB (2 yr) Pwr Level Tests /ML2530,LO
  1.174  ENDIF

  1.175  MATH         @RsltLvlFreq_8GHz = @RsltFreq

# 10 GHz
  1.176  MATH         @FreqGHz = "10.0"; @RsltFreq = @RsltLvlFreq_10GHz
  1.177  CALL         Sub MG369XB Set Max Power

  1.178  IF           (@Iteration == 1) && (@MaxPower > +19)
  1.179  CALL         Sub MG369XB (2 yr) Pwr Lvl Tests >19 dBm /ML2437
  1.180  ELSEIF       (@Iteration == 2)
  1.181  CALL         Sub MG369XB (2 yr) Pwr Lvl Tests <=19 dBm Opt 2 /ML2437
  1.182  MATH         @ML2430A_AccWNeg20dBm10GHz = @ML2430A_AccWNeg20dBm
  1.183  MATH         @ML2430A_AccWNeg50dBm10GHz = @ML2430A_AccWNeg50dBm
  1.184  ELSEIF       (@Iteration == 3)
  1.185  MATH         @LoFreqMHz = 9991.49
  1.186  CALL         Sub MG369XB (2 yr) Pwr Level Tests /ML2530,LO
  1.187  ENDIF

  1.188  MATH         @RsltLvlFreq_10GHz = @RsltFreq

  1.189  IF           @MaxFreq > 10E+9
# 12 GHz
  1.190  MATH         @FreqGHz = "12.0"; @RsltFreq = @RsltLvlFreq_12GHz
  1.191  CALL         Sub MG369XB Set Max Power

  1.192  IF           (@Iteration == 1) && (@MaxPower > +19)
  1.193  CALL         Sub MG369XB (2 yr) Pwr Lvl Tests >19 dBm /ML2437
  1.194  ELSEIF       (@Iteration == 2)
  1.195  CALL         Sub MG369XB (2 yr) Pwr Lvl Tests <=19 dBm Opt 2 /ML2437
  1.196  MATH         @ML2430A_AccWNeg20dBm12GHz = @ML2430A_AccWNeg20dBm
  1.197  MATH         @ML2430A_AccWNeg50dBm12GHz = @ML2430A_AccWNeg50dBm
  1.198  ELSEIF       (@Iteration == 3)
  1.199  MATH         @LoFreqMHz = 11991.49
  1.200  CALL         Sub MG369XB (2 yr) Pwr Level Tests /ML2530,LO
  1.201  ENDIF

  1.202  MATH         @RsltLvlFreq_12GHz = @RsltFreq

# 14 GHz
  1.203  MATH         @FreqGHz = "14.0"; @RsltFreq = @RsltLvlFreq_14GHz
  1.204  CALL         Sub MG369XB Set Max Power

  1.205  IF           (@Iteration == 1) && (@MaxPower > +19)
  1.206  CALL         Sub MG369XB (2 yr) Pwr Lvl Tests >19 dBm /ML2437
  1.207  ELSEIF       (@Iteration == 2)
  1.208  CALL         Sub MG369XB (2 yr) Pwr Lvl Tests <=19 dBm Opt 2 /ML2437
  1.209  MATH         @ML2430A_AccWNeg20dBm14GHz = @ML2430A_AccWNeg20dBm
  1.210  MATH         @ML2430A_AccWNeg50dBm14GHz = @ML2430A_AccWNeg50dBm
  1.211  ELSEIF       (@Iteration == 3)
  1.212  MATH         @LoFreqMHz = 13991.49
  1.213  CALL         Sub MG369XB (2 yr) Pwr Level Tests /ML2530,LO
  1.214  ENDIF

  1.215  MATH         @RsltLvlFreq_14GHz = @RsltFreq

# 16 GHz
  1.216  MATH         @FreqGHz = "16.0"; @RsltFreq = @RsltLvlFreq_16GHz
  1.217  CALL         Sub MG369XB Set Max Power

  1.218  IF           (@Iteration == 1) && (@MaxPower > +19)
  1.219  CALL         Sub MG369XB (2 yr) Pwr Lvl Tests >19 dBm /ML2437
  1.220  ELSEIF       (@Iteration == 2)
  1.221  CALL         Sub MG369XB (2 yr) Pwr Lvl Tests <=19 dBm Opt 2 /ML2437
  1.222  MATH         @ML2430A_AccWNeg20dBm16GHz = @ML2430A_AccWNeg20dBm
  1.223  MATH         @ML2430A_AccWNeg50dBm16GHz = @ML2430A_AccWNeg50dBm
  1.224  ELSEIF       (@Iteration == 3)
  1.225  MATH         @LoFreqMHz = 15991.49
  1.226  CALL         Sub MG369XB (2 yr) Pwr Level Tests /ML2530,LO
  1.227  ENDIF

  1.228  MATH         @RsltLvlFreq_16GHz = @RsltFreq

# 18 GHz
  1.229  MATH         @FreqGHz = "18.0"; @RsltFreq = @RsltLvlFreq_18GHz
  1.230  CALL         Sub MG369XB Set Max Power

  1.231  IF           (@Iteration == 1) && (@MaxPower > +19)
  1.232  CALL         Sub MG369XB (2 yr) Pwr Lvl Tests >19 dBm /ML2437
  1.233  ELSEIF       (@Iteration == 2)
  1.234  CALL         Sub MG369XB (2 yr) Pwr Lvl Tests <=19 dBm Opt 2 /ML2437
  1.235  MATH         @ML2430A_AccWNeg20dBm18GHz = @ML2430A_AccWNeg20dBm
  1.236  MATH         @ML2430A_AccWNeg50dBm18GHz = @ML2430A_AccWNeg50dBm
  1.237  ELSEIF       (@Iteration == 3)
  1.238  MATH         @LoFreqMHz = 17991.49
  1.239  CALL         Sub MG369XB (2 yr) Pwr Level Tests /ML2530,LO
  1.240  ENDIF

  1.241  MATH         @RsltLvlFreq_18GHz = @RsltFreq

# 20 GHz
  1.242  MATH         @FreqGHz = "20.0"; @RsltFreq = @RsltLvlFreq_20GHz
  1.243  CALL         Sub MG369XB Set Max Power

  1.244  IF           (@Iteration == 1) && (@MaxPower > +19)
  1.245  CALL         Sub MG369XB (2 yr) Pwr Lvl Tests >19 dBm /ML2437
  1.246  ELSEIF       (@Iteration == 2)
  1.247  CALL         Sub MG369XB (2 yr) Pwr Lvl Tests <=19 dBm Opt 2 /ML2437
  1.248  MATH         @ML2430A_AccWNeg20dBm20GHz = @ML2430A_AccWNeg20dBm
  1.249  MATH         @ML2430A_AccWNeg50dBm20GHz = @ML2430A_AccWNeg50dBm
  1.250  ELSEIF       (@Iteration == 3)
  1.251  MATH         @LoFreqMHz = 19991.49
  1.252  CALL         Sub MG369XB (2 yr) Pwr Level Tests /ML2530,LO
  1.253  ENDIF

  1.254  MATH         @RsltLvlFreq_20GHz = @RsltFreq

  1.255  IF           ; @MaxFreq > 20E+9
# 22 GHz
  1.256  MATH         @FreqGHz = "22.0"; @RsltFreq = @RsltLvlFreq_22GHz
  1.257  CALL         Sub MG369XB Set Max Power

  1.258  IF           (@Iteration == 1) && (@MaxPower > +19)
  1.259  CALL         Sub MG369XB (2 yr) Pwr Lvl Tests >19 dBm /ML2437
  1.260  ELSEIF       (@Iteration == 2)
  1.261  CALL         Sub MG369XB (2 yr) Pwr Lvl Tests <=19 dBm Opt 2 /ML2437
  1.262  MATH         @ML2430A_AccWNeg20dBm22GHz = @ML2430A_AccWNeg20dBm
  1.263  MATH         @ML2430A_AccWNeg50dBm22GHz = @ML2430A_AccWNeg50dBm
  1.264  ELSEIF       (@Iteration == 3)
  1.265  MATH         @LoFreqMHz = 21991.49
  1.266  CALL         Sub MG369XB (2 yr) Pwr Level Tests /ML2530,LO
  1.267  ENDIF

  1.268  MATH         @RsltLvlFreq_22GHz = @RsltFreq

# 24 GHz
  1.269  MATH         @FreqGHz = "24.0"; @RsltFreq = @RsltLvlFreq_24GHz
  1.270  CALL         Sub MG369XB Set Max Power

  1.271  IF           (@Iteration == 1) && (@MaxPower > +19)
  1.272  CALL         Sub MG369XB (2 yr) Pwr Lvl Tests >19 dBm /ML2437
  1.273  ELSEIF       (@Iteration == 2)
  1.274  CALL         Sub MG369XB (2 yr) Pwr Lvl Tests <=19 dBm Opt 2 /ML2437
  1.275  MATH         @ML2430A_AccWNeg20dBm24GHz = @ML2430A_AccWNeg20dBm
  1.276  MATH         @ML2430A_AccWNeg50dBm24GHz = @ML2430A_AccWNeg50dBm
  1.277  ELSEIF       (@Iteration == 3)
  1.278  MATH         @LoFreqMHz = 23991.49
  1.279  CALL         Sub MG369XB (2 yr) Pwr Level Tests /ML2530,LO
  1.280  ENDIF

  1.281  MATH         @RsltLvlFreq_24GHz = @RsltFreq

# 26 GHz
  1.282  MATH         @FreqGHz = "26.0"; @RsltFreq = @RsltLvlFreq_26GHz
  1.283  CALL         Sub MG369XB Set Max Power

  1.284  IF           (@Iteration == 1) && (@MaxPower > +19)
  1.285  CALL         Sub MG369XB (2 yr) Pwr Lvl Tests >19 dBm /ML2437
  1.286  ELSEIF       (@Iteration == 2)
  1.287  CALL         Sub MG369XB (2 yr) Pwr Lvl Tests <=19 dBm Opt 2 /ML2437
  1.288  MATH         @ML2430A_AccWNeg20dBm26GHz = @ML2430A_AccWNeg20dBm
  1.289  MATH         @ML2430A_AccWNeg50dBm26GHz = @ML2430A_AccWNeg50dBm
  1.290  ELSEIF       (@Iteration == 3)
  1.291  MATH         @LoFreqMHz = 25991.49
  1.292  CALL         Sub MG369XB (2 yr) Pwr Level Tests /ML2530,LO
  1.293  ENDIF

  1.294  MATH         @RsltLvlFreq_26GHz = @RsltFreq

# 28 GHz
  1.295  MATH         @FreqGHz = "28.0"; @RsltFreq = @RsltLvlFreq_28GHz
  1.296  CALL         Sub MG369XB Set Max Power

  1.297  IF           (@Iteration == 1) && (@MaxPower > +19)
  1.298  CALL         Sub MG369XB (2 yr) Pwr Lvl Tests >19 dBm /ML2437
  1.299  ELSEIF       (@Iteration == 2)
  1.300  CALL         Sub MG369XB (2 yr) Pwr Lvl Tests <=19 dBm Opt 2 /ML2437
  1.301  MATH         @ML2430A_AccWNeg20dBm28GHz = @ML2430A_AccWNeg20dBm
  1.302  MATH         @ML2430A_AccWNeg50dBm28GHz = @ML2430A_AccWNeg50dBm
  1.303  ELSEIF       (@Iteration == 3)
  1.304  MATH         @LoFreqMHz = 27991.49
  1.305  CALL         Sub MG369XB (2 yr) Pwr Level Tests /ML2530,LO
  1.306  ENDIF

  1.307  MATH         @RsltLvlFreq_28GHz = @RsltFreq

# 30 GHz
  1.308  MATH         @FreqGHz = "30.0"; @RsltFreq = @RsltLvlFreq_30GHz
  1.309  CALL         Sub MG369XB Set Max Power

  1.310  IF           (@Iteration == 1) && (@MaxPower > +19)
  1.311  CALL         Sub MG369XB (2 yr) Pwr Lvl Tests >19 dBm /ML2437
  1.312  ELSEIF       (@Iteration == 2)
  1.313  CALL         Sub MG369XB (2 yr) Pwr Lvl Tests <=19 dBm Opt 2 /ML2437
  1.314  MATH         @ML2430A_AccWNeg20dBm30GHz = @ML2430A_AccWNeg20dBm
  1.315  MATH         @ML2430A_AccWNeg50dBm30GHz = @ML2430A_AccWNeg50dBm
  1.316  ELSEIF       (@Iteration == 3)
  1.317  MATH         @LoFreqMHz = 29991.49
  1.318  CALL         Sub MG369XB (2 yr) Pwr Level Tests /ML2530,LO
  1.319  ENDIF

  1.320  MATH         @RsltLvlFreq_30GHz = @RsltFreq

  1.321  IF           @MaxFreq > 30E+9
# 32 GHz
  1.322  MATH         @FreqGHz = "32.0"; @RsltFreq = @RsltLvlFreq_32GHz
  1.323  CALL         Sub MG369XB Set Max Power

  1.324  IF           (@Iteration == 1) && (@MaxPower > +19)
  1.325  CALL         Sub MG369XB (2 yr) Pwr Lvl Tests >19 dBm /ML2437
  1.326  ELSEIF       (@Iteration == 2)
  1.327  CALL         Sub MG369XB (2 yr) Pwr Lvl Tests <=19 dBm Opt 2 /ML2437
  1.328  MATH         @ML2430A_AccWNeg20dBm32GHz = @ML2430A_AccWNeg20dBm
  1.329  MATH         @ML2430A_AccWNeg50dBm32GHz = @ML2430A_AccWNeg50dBm
  1.330  ELSEIF       (@Iteration == 3)
  1.331  MATH         @LoFreqMHz = 31991.49
  1.332  CALL         Sub MG369XB (2 yr) Pwr Level Tests /ML2530,LO
  1.333  ENDIF

  1.334  MATH         @RsltLvlFreq_32GHz = @RsltFreq

# 34 GHz
  1.335  MATH         @FreqGHz = "34.0"; @RsltFreq = @RsltLvlFreq_34GHz
  1.336  CALL         Sub MG369XB Set Max Power

  1.337  IF           (@Iteration == 1) && (@MaxPower > +19)
  1.338  CALL         Sub MG369XB (2 yr) Pwr Lvl Tests >19 dBm /ML2437
  1.339  ELSEIF       (@Iteration == 2)
  1.340  CALL         Sub MG369XB (2 yr) Pwr Lvl Tests <=19 dBm Opt 2 /ML2437
  1.341  MATH         @ML2430A_AccWNeg20dBm34GHz = @ML2430A_AccWNeg20dBm
  1.342  MATH         @ML2430A_AccWNeg50dBm34GHz = @ML2430A_AccWNeg50dBm
  1.343  ELSEIF       (@Iteration == 3)
  1.344  MATH         @LoFreqMHz = 33991.49
  1.345  CALL         Sub MG369XB (2 yr) Pwr Level Tests /ML2530,LO
  1.346  ENDIF

  1.347  MATH         @RsltLvlFreq_34GHz = @RsltFreq

# 36 GHz
  1.348  MATH         @FreqGHz = "36.0"; @RsltFreq = @RsltLvlFreq_36GHz
  1.349  CALL         Sub MG369XB Set Max Power

  1.350  IF           (@Iteration == 1) && (@MaxPower > +19)
  1.351  CALL         Sub MG369XB (2 yr) Pwr Lvl Tests >19 dBm /ML2437
  1.352  ELSEIF       (@Iteration == 2)
  1.353  CALL         Sub MG369XB (2 yr) Pwr Lvl Tests <=19 dBm Opt 2 /ML2437
  1.354  MATH         @ML2430A_AccWNeg20dBm36GHz = @ML2430A_AccWNeg20dBm
  1.355  MATH         @ML2430A_AccWNeg50dBm36GHz = @ML2430A_AccWNeg50dBm
  1.356  ELSEIF       (@Iteration == 3)
  1.357  MATH         @LoFreqMHz = 35991.49
  1.358  CALL         Sub MG369XB (2 yr) Pwr Level Tests /ML2530,LO
  1.359  ENDIF

  1.360  MATH         @RsltLvlFreq_36GHz = @RsltFreq

# 38 GHz
  1.361  MATH         @FreqGHz = "38.0"; @RsltFreq = @RsltLvlFreq_38GHz
  1.362  CALL         Sub MG369XB Set Max Power

  1.363  IF           (@Iteration == 1) && (@MaxPower > +19)
  1.364  CALL         Sub MG369XB (2 yr) Pwr Lvl Tests >19 dBm /ML2437
  1.365  ELSEIF       (@Iteration == 2)
  1.366  CALL         Sub MG369XB (2 yr) Pwr Lvl Tests <=19 dBm Opt 2 /ML2437
  1.367  MATH         @ML2430A_AccWNeg20dBm38GHz = @ML2430A_AccWNeg20dBm
  1.368  MATH         @ML2430A_AccWNeg50dBm38GHz = @ML2430A_AccWNeg50dBm
  1.369  ELSEIF       (@Iteration == 3)
  1.370  MATH         @LoFreqMHz = 37991.49
  1.371  CALL         Sub MG369XB (2 yr) Pwr Level Tests /ML2530,LO
  1.372  ENDIF

  1.373  MATH         @RsltLvlFreq_38GHz = @RsltFreq

# 40 GHz
  1.374  MATH         @FreqGHz = "40.0"; @RsltFreq = @RsltLvlFreq_40GHz
  1.375  CALL         Sub MG369XB Set Max Power

  1.376  IF           (@Iteration == 1) && (@MaxPower > +19)
  1.377  CALL         Sub MG369XB (2 yr) Pwr Lvl Tests >19 dBm /ML2437
  1.378  ELSEIF       (@Iteration == 2)
  1.379  CALL         Sub MG369XB (2 yr) Pwr Lvl Tests <=19 dBm Opt 2 /ML2437
  1.380  MATH         @ML2430A_AccWNeg20dBm40GHz = @ML2430A_AccWNeg20dBm
  1.381  MATH         @ML2430A_AccWNeg50dBm40GHz = @ML2430A_AccWNeg50dBm
  1.382  ELSEIF       (@Iteration == 3)
  1.383  MATH         @LoFreqMHz = 39991.49
  1.384  CALL         Sub MG369XB (2 yr) Pwr Level Tests /ML2530,LO
  1.385  ENDIF

  1.386  MATH         @RsltLvlFreq_40GHz = @RsltFreq

# Note, 50, 60, & 67 GHz are not tested at > +19 dBm or < -60 dBm.
  1.387  IF           @MaxFreq > 40E+9
# 50 GHz
  1.388  MATH         @FreqGHz = "50.0"
  1.389  CALL         Sub MG369XB Set Max Power

  1.390  IF           (@Iteration == 2)
  1.391  MATH         @RsltFreq = 0
  1.392  CALL         Sub MG369XB (2 yr) Pwr Lvl Tests <=19 dBm Opt 2 /ML2437
  1.393  ENDIF

  1.394  MATH         @RsltLvlFreq_50GHz = @RsltFreq

  1.395  IF           @MaxFreq > 50E+9
# 60 GHz
  1.396  MATH         @FreqGHz = "60.0"
  1.397  CALL         Sub MG369XB Set Max Power

  1.398  IF           (@Iteration == 2)
  1.399  MATH         @RsltFreq = 0
  1.400  CALL         Sub MG369XB (2 yr) Pwr Lvl Tests <=19 dBm Opt 2 /ML2437
  1.401  ENDIF

  1.402  MATH         @RsltLvlFreq_60GHz = @RsltFreq

  1.403  IF           @MaxFreq > 65E+9
# 67 GHz
  1.404  MATH         @FreqGHz = "67.0"
  1.405  CALL         Sub MG369XB Set Max Power

  1.406  IF           (@Iteration == 2)
  1.407  MATH         @RsltFreq = 0
  1.408  CALL         Sub MG369XB (2 yr) Pwr Lvl Tests <=19 dBm Opt 2 /ML2437
  1.409  ENDIF

  1.410  MATH         @RsltLvlFreq_67GHz = @RsltFreq
  1.411  ELSE
# 65 GHz
  1.412  MATH         @FreqGHz = "65.0"
  1.413  CALL         Sub MG369XB Set Max Power

  1.414  IF           (@Iteration == 2)
  1.415  MATH         @RsltFreq = 0
  1.416  CALL         Sub MG369XB (2 yr) Pwr Lvl Tests <=19 dBm Opt 2 /ML2437
  1.417  ENDIF

  1.418  MATH         @RsltLvlFreq_65GHz = @RsltFreq
  1.419  ENDIF        ; @MaxFreq > 65E+9

  1.420  ENDIF        ; @MaxFreq > 50E+9

  1.421  ENDIF        ; @MaxFreq > 40E+9

  1.422  ENDIF        ; @MaxFreq > 30E+9

  1.423  ENDIF        ; @MaxFreq > 20E+9

  1.424  ENDIF        ; @MaxFreq > 10E+9

  1.425  IF           @Iteration == 3
  1.426  MATH         Done = 1
  1.427  ENDIF

  1.428  MATH         @Iteration = @Iteration + 1
  1.429  UNTIL        Done

  1.430  HEAD
  1.431  CALL         Sub MG369XB Reset & SRQ Masks
  1.432  CALL         Sub Reset /LO
  1.433  ML2530       Reset
  1.434  ML2437       Reset
  1.435  END
