﻿Anritsu Company                                             MET/CAL Procedure
=============================================================================
INSTRUMENT:            Sub MG369XB (2 yr) Power Level Test /ML2437
INSTRUMENT:            Sub MG369XB (2 yr) Maximum Leveled Power Test /ML2437
DATE:                  2009-07-27 15:44:52
AUTHOR:                Fluke
REVISION:              $Revision: 2619 $
ADJUSTMENT THRESHOLD:  70%
NUMBER OF TESTS:       5
NUMBER OF LINES:       175
CONFIGURATION:         Anritsu ML2437A
=============================================================================
#
#  Procedure Author:
#        DAC
#
#  Model(s) Covered:
#        MG369XB
#
#  Compatibility:
#        MET/CAL 7.20E or later
#
#  Subprocedures:
#        Sub MG369XB Connection /ML2437
#        Sub MG369XB Min/Max Power Sweep /ML2437
#        Sub Anritsu Power Sensor Get Series
#        Sub Anritsu 41KC-S Get Attenuation
#        Sub Anritsu 41V-S Get Attenuation
#
#  Required Files:
#        None
#
#  Additional Equipment Required:
#        None
#
#  The copyright for this procedure is owned by Fluke Corporation.
#
 STEP    FSC    RANGE NOMINAL        TOLERANCE     MOD1        MOD2  3  4 CON

  1.001  JMPL         POWER_LEVEL_TEST             PSUB("Power Level Test")
  1.002  JMPL         MAX_LEVELED_POWER_TEST       PSUB("Maximum Leveled")
  1.003  DISP         Called subprocedure not found!
  1.004  END

  1.005  EVAL   Increment step number

# =====  Sub MG369XB (2 yr) Power Level Test /ML2437  =======================

  2.001  LABEL        POWER_LEVEL_TEST

  2.002  IF           NOT(@RsltFreq)
  2.003  MATH         Freq = ENGR_NSD(@FreqGHz, "GHz", @RsltFreqNSD)
  2.004  RSLT         =
  2.005  RSLT         = [V Freq]
  2.006  MATH         @RsltFreq = 1
  2.007  ENDIF

  2.008  TARGET       -p
  2.009  TSET         MEAS = SA; CPT = [V @LvldBm]; NTHROW = 1
  2.010  CALL         Sub MG369XB Connection /ML2437

  2.011  IF           FIND(@MG369XB_ML2430_Con, "10dB", 1)
  2.012  MATH         Power = @LvldBm - 10
  2.013  ELSE
  2.014  MATH         Power = @LvldBm
  2.015  ENDIF

# Use averaging for thermal sensors.
  2.016  IF           ZCMP(@PS_Series, "MA242X")

  2.017  IF           @LvldBm > -15
  2.018  MATH         AvgCnt = 32
  2.019  ELSE
  2.020  MATH         AvgCnt = 64
  2.021  ENDIF

  2.022  ML2437       AveragingMode = Repeat; AverageCount = [V AvgCnt]; Setup
  2.022  ML2437       PowerSensor = [V @PS]
  2.022  ML2437       UUTSWR = [V @MG369XB_SWR]
  2.022  ML2437       +Power = [V Power] dBm; Freq = [V @FreqGHz] GHz
  2.023  ELSE
  2.024  ML2437       AveragingMode = Auto
  2.024  ML2437       PowerSensor = [V @PS]; Setup
  2.024  ML2437       UUTSWR = [V @MG369XB_SWR]
  2.024  ML2437       +Power = [V Power] dBm; Freq = [V @FreqGHz] GHz
  2.025  ENDIF

# 50 ms settling for worst case power level switching.
  2.026  IEEE         RF0[D50]CF1[V @FreqGHz]GHL1[V @LvldBm]DM[D50]

# Anritsu recommends you zero the sensor on the UUT if taking a measurement
# near the sensitivity of the sensor.
  2.027  IF           Power <= @PS_MinLvl + 20
  2.028  ML2437       Zero; PowerSensor = [V @PS]
  2.029  ENDIF
  2.030  IEEE         RF1[D250]
  2.031  TARGET       -m

  2.032  IF           ZCMP(@PS_Series, "MA242X")
  2.033  ML2437       AveragingMode = Repeat; AverageCount = [V AvgCnt]; Read
  2.033  ML2437       PowerSensor = [V @PS]
  2.033  ML2437       UUTSWR = [V @MG369XB_SWR]
  2.033  ML2437       +Power = [V Power] dBm; Freq = [V @FreqGHz] GHz
  2.034  ELSE
  2.035  ML2437       AveragingMode = Auto
  2.035  ML2437       PowerSensor = [V @PS]; Read
  2.035  ML2437       UUTSWR = [V @MG369XB_SWR]
  2.035  ML2437       +Power = [V Power] dBm; Freq = [V @FreqGHz] GHz
  2.036  ENDIF

# Get the accuracy of the ML2430A measurement.  The -20 dBm or -50 dBm
# measurement accuracy if RSS'd with the accuracy of the ML2530A relative
# measurements, for MG369XB with Option 2.
  2.037  MATH         @ML2430A_AccW = REFACC()

  2.038  IF           FIND(@MG369XB_ML2430_Con, "10dB", 1)

  2.039  IF           ZCMP(@MG369XB_Con, "K")
  2.040  CALL         Sub Anritsu 41KC-S Get Attenuation
  2.041  ELSE
  2.042  CALL         Sub Anritsu 41V-S Get Attenuation
  2.043  ENDIF

  2.044  MATH         MEM = MEM + @AnritsuAttenVal
  2.045  ENDIF

# save power level measurements to be used when calculating the offset for
# low-level measurements taken by the ML2530
  2.046  IF           @LvldBm == -20
  2.047  MATH         PUT("MG369XB_lvl_-20dBm_" & @FreqGHz, MEM)
  2.048  ELSEIF       @LvldBm == -50
  2.049  MATH         PUT("MG369XB_lvl_-50dBm_" & @FreqGHz, MEM)
  2.050  ENDIF

  2.051  IF           @FreqGHz > 40
  2.052  TOL          1.50U
  2.053  ELSEIF       @FreqGHz > 0.020 && NOT(@Opt_15)
  2.054  TOL          1.00U
  2.055  ELSE
  2.056  TOL          1.5U
  2.057  ENDIF

  2.058  MATH         MEM1 = @LvldBm
  2.059  MEMC   25    dBm            TOL

  3.001  END

  3.002  EVAL   Increment step number

# =====  Sub MG369XB (2 yr) Maximum Leveled Power Test /ML2437  =============

  4.001  LABEL        MAX_LEVELED_POWER_TEST
  4.002  HEAD         MAXIMUM LEVELED POWER
# Get the maximum leveled power for the specified frequency range.
  4.003  MATH         @FreqGHz = @StopFreq / 1E+9
  4.004  CALL         Sub MG369XB Set Max Power
  4.005  TSET         MEAS = SA; CPT = [V @MaxPower]; NTHROW = 0; NMEAS = 1
  4.006  MATH         Start = ENGR_NSD(@StartFreq, "Hz", 3)
  4.007  MATH         Stop  = ENGR_NSD(@StopFreq, "Hz", 3)
  4.008  RSLT         =
  4.009  RSLT         = [V Start] to [V Stop]
  4.010  TARGET
  4.011  CALL         Sub MG369XB Min/Max Power Sweep /ML2437
  4.012  MATH         Freq = ENGR_NSD(@MinPwrFreq, "Hz", 3)
  4.013  TSET         TDESC = Min Power Level @ [V Freq]
  4.014  MATH         MEM = @MinPwr; L[1] = PCTTODBW_D(@MinPwrAcc)
  4.015  ACC          dBm            L1U                                   +W
  4.016  MATH         MEM1 = @MaxPower
  4.017  MEMC         dBm            +0.0U -30.0U

  5.001  END
