﻿Anritsu Company                                             MET/CAL Procedure
=============================================================================
INSTRUMENT:            Sub MG369XB (2 yr) Pwr Level Tests /ML2530
INSTRUMENT:            Sub MG369XB (2 yr) Pwr Level Tests /ML2530,LO
DATE:                  2009-04-22 15:44:19
AUTHOR:                Fluke
REVISION:              $Revision: 2619 $
ADJUSTMENT THRESHOLD:  70%
NUMBER OF TESTS:       3
NUMBER OF LINES:       440
CONFIGURATION:         Anritsu ML2530A
CONFIGURATION:         Anritsu 68369B
=============================================================================
#
#  Procedure Author:
#        DAC
#
#  Model(s) Covered:
#        MG369XB w/Opt 2: "Step Attenuators"
#
#  Compatibility:
#        MET/CAL 7.20E or later
#
#  Subprocedures:
#        Sub MG369XB (2 yr) Pwr Level Test /ML2530
#        Sub MG369XB (2 yr) Pwr Level Test /ML2530,LO
#        Sub MG369XB ML2530A Relative Range Cal
#        Sub MG369XB Reset & SRQ Masks
#        Sub Apply /LO
#        Sub Reset /LO
#
#  Required Files:
#        None
#
#  Additional Equipment Required:
#        None
#
#  The copyright for this procedure is owned by Fluke Corporation.
#
 STEP    FSC    RANGE NOMINAL        TOLERANCE     MOD1        MOD2  3  4 CON

# Dummy statements to force header to contain reference used in subprocedure.
  1.001  IF           0
  1.002  IEEE         [@LO]
  1.003  ENDIF

  1.004  MATH         Freq = ENGR_NSD(@FreqGHz, "GHz", 3)
  1.005  CALL         Sub MG369XB Reset & SRQ Masks

# The power level at which the tests start measuring is based on the minimum
# power level of the power sensor used at the current frequency.  So the
# first step is to determine what power sensor would be used at the current
# freq and get the power level properties of that sensor.
  1.006  CALL         Sub MG369XB Get Specified Power Sensor
  1.007  CALL         Sub Anritsu Power Sensor Get Series
  1.008  CALL         Sub Anritsu Power Sensor Get Dynamic Range

# Power level accuracy is specified based on the attenuation below max power
# and the frequency.  Calculate the lowest power level for which there is an
# accuracy spec.
  1.009  IF           @FreqGHz > 50
  1.010  MATH         Lowest_power_level = @MaxPower - 25
  1.011  ELSEIF       @FreqGHz > 40
  1.012  MATH         Lowest_power_level = @MaxPower - 60
  1.013  ELSE
  1.014  MATH         Lowest_power_level = @MaxPower - 100
  1.015  ENDIF

# DO NOT change the order these JMPL statements!
  1.016  JMPL         PWR_LEVEL_TESTS_ML2530A_LO   PSUB("ML2530,LO")
  1.017  JMPL         PWR_LEVEL_TESTS_ML2530A      PSUB("ML2530")
  1.018  DISP         Called subprocedure not found!
  1.019  END


  1.020  EVAL   Increment step number

# =====  Sub MG369XB (2 yr) Pwr Level Tests /ML2530  ========================

  2.001  LABEL        PWR_LEVEL_TESTS_ML2530A
  2.002  CALL         Sub MG369XB Connection /ML2530
  2.003  CALL         Sub MG369XB ML2530A Relative Range Cal

  2.004  HEAD         DETERMINE OFFSET @ [V Freq]

  2.005  IF           @PS_MinLvl > -60
  2.006  MATH         Range = +20
  2.007  MATH         OffsetLvl = -20
  2.008  MATH         ActualLvl = GET("MG369XB_lvl_-20dBm_" & @FreqGHz)
  2.009  ELSE
  2.010  MATH         Range = -25
  2.011  MATH         OffsetLvl = -50
  2.012  MATH         ActualLvl = GET("MG369XB_lvl_-50dBm_" & @FreqGHz)
  2.013  ENDIF

  2.014  LABEL        OFFSET_ML2530
  2.015  TARGET
  2.016  ML2530       NoSensorModuleRequired; Setup
  2.016  ML2530       Bandwidth = 10 Hz; AverageCount = 1
  2.016  ML2530       Freq = [V Freq]; FreqSpan = 10 kHz
  2.016  ML2530       +Level = [V OffsetLvl] dBm; Range = [V Range] dBm
  2.017  IEEE         CF1[V @FreqGHz]GHL1[V OffsetLvl]DMRF1[D50]
  2.018  ML2530       NoSensorModuleRequired; Read
  2.018  ML2530       Bandwidth = 10 Hz; AverageCount = 1
  2.018  ML2530       Freq = [V Freq]; FreqSpan = 10 kHz
  2.018  ML2530       +Level = [V OffsetLvl] dBm; Range = [V Range] dBm
  2.019  MATH         @Offset = ActualLvl - MEM

# Make sure the computed offset value is reasonable.
  2.020  IF           ABS(@Offset) > 2
  2.021  OPBR         -z |Offset| is greater than 2 dB!
  2.021  OPBR
  2.021  OPBR         Do you wish to repeat the offset calculation?
  2.022  MATH         Repeat = MEM1

# Initialize connection variable, so connection is displayed.
  2.023  IF           Repeat
  2.024  MATH         @MG369XB_ML2530A_Con = ""
  2.025  CALL         Sub MG369XB Connection /ML2530
  2.026  ENDIF

  2.027  ELSE
  2.028  MATH         Repeat = 0
  2.029  ENDIF

  2.030  JMPL         OFFSET_ML2530                Repeat

  2.031  IF           @PS_MinLvl > -50
  2.032  MATH         @LvldBm = -25

  2.033  IF           @LvldBm >= Lowest_power_level
  2.034  HEAD         POWER LEVEL ACCURACY: [V @LvldBm] dBm @ [V Freq]
  2.035  CALL         Sub MG369XB (2 yr) Pwr Level Test /ML2530
  2.036  ENDIF

  2.037  MATH         @LvldBm = -30

  2.038  IF           @LvldBm >= Lowest_power_level
  2.039  HEAD         POWER LEVEL ACCURACY: [V @LvldBm] dBm @ [V Freq]
  2.040  CALL         Sub MG369XB (2 yr) Pwr Level Test /ML2530
  2.041  ENDIF

  2.042  MATH         @LvldBm = -35

  2.043  IF           @LvldBm >= Lowest_power_level
  2.044  HEAD         POWER LEVEL ACCURACY: [V @LvldBm] dBm @ [V Freq]
  2.045  CALL         Sub MG369XB (2 yr) Pwr Level Test /ML2530
  2.046  ENDIF

  2.047  MATH         @LvldBm = -40

  2.048  IF           @LvldBm >= Lowest_power_level
  2.049  HEAD         POWER LEVEL ACCURACY: [V @LvldBm] dBm @ [V Freq]
  2.050  CALL         Sub MG369XB (2 yr) Pwr Level Test /ML2530
  2.051  ENDIF

  2.052  MATH         @LvldBm = -45

  2.053  IF           @LvldBm >= Lowest_power_level
  2.054  HEAD         POWER LEVEL ACCURACY: [V @LvldBm] dBm @ [V Freq]
  2.055  CALL         Sub MG369XB (2 yr) Pwr Level Test /ML2530
  2.056  ENDIF

  2.057  MATH         @LvldBm = -50

  2.058  IF           @LvldBm >= Lowest_power_level
  2.059  HEAD         POWER LEVEL ACCURACY: [V @LvldBm] dBm @ [V Freq]
  2.060  CALL         Sub MG369XB (2 yr) Pwr Level Test /ML2530
  2.061  ENDIF

  2.062  ENDIF        ; @PS_MinLvl > -50

  2.063  IF           @PS_MinLvl > -60
  2.064  MATH         @LvldBm = -55

  2.065  IF           @LvldBm >= Lowest_power_level
  2.066  HEAD         POWER LEVEL ACCURACY: [V @LvldBm] dBm @ [V Freq]
  2.067  CALL         Sub MG369XB (2 yr) Pwr Level Test /ML2530
  2.068  ENDIF

  2.069  MATH         @LvldBm = -60

  2.070  IF           @LvldBm >= Lowest_power_level
  2.071  HEAD         POWER LEVEL ACCURACY: [V @LvldBm] dBm @ [V Freq]
  2.072  CALL         Sub MG369XB (2 yr) Pwr Level Test /ML2530
  2.073  ENDIF

  2.074  ENDIF        ; @PS_MinLvl > -60

  2.075  MATH         @LvldBm = -65

  2.076  IF           @LvldBm >= Lowest_power_level
  2.077  HEAD         POWER LEVEL ACCURACY: [V @LvldBm] dBm @ [V Freq]
  2.078  CALL         Sub MG369XB (2 yr) Pwr Level Test /ML2530
  2.079  ENDIF

  2.080  MATH         @LvldBm = -70

  2.081  IF           @LvldBm >= Lowest_power_level
  2.082  HEAD         POWER LEVEL ACCURACY: [V @LvldBm] dBm @ [V Freq]
  2.083  CALL         Sub MG369XB (2 yr) Pwr Level Test /ML2530
  2.084  ENDIF

  2.085  MATH         @LvldBm = -75

  2.086  IF           @LvldBm >= Lowest_power_level
  2.087  HEAD         POWER LEVEL ACCURACY: [V @LvldBm] dBm @ [V Freq]
  2.088  CALL         Sub MG369XB (2 yr) Pwr Level Test /ML2530
  2.089  ENDIF

  2.090  MATH         @LvldBm = -80

  2.091  IF           @LvldBm >= Lowest_power_level
  2.092  HEAD         POWER LEVEL ACCURACY: [V @LvldBm] dBm @ [V Freq]
  2.093  CALL         Sub MG369XB (2 yr) Pwr Level Test /ML2530
  2.094  ENDIF

  2.095  MATH         @LvldBm = -85

  2.096  IF           @LvldBm >= Lowest_power_level
  2.097  HEAD         POWER LEVEL ACCURACY: [V @LvldBm] dBm @ [V Freq]
  2.098  CALL         Sub MG369XB (2 yr) Pwr Level Test /ML2530
  2.099  ENDIF

  2.100  MATH         @LvldBm = -90

  2.101  IF           @LvldBm >= Lowest_power_level
  2.102  HEAD         POWER LEVEL ACCURACY: [V @LvldBm] dBm @ [V Freq]
  2.103  CALL         Sub MG369XB (2 yr) Pwr Level Test /ML2530
  2.104  ENDIF

  2.105  MATH         @LvldBm = -95

  2.106  IF           @LvldBm >= Lowest_power_level
  2.107  HEAD         POWER LEVEL ACCURACY: [V @LvldBm] dBm @ [V Freq]
  2.108  CALL         Sub MG369XB (2 yr) Pwr Level Test /ML2530
  2.109  ENDIF

  2.110  MATH         @LvldBm = -100

  2.111  IF           @LvldBm >= Lowest_power_level
  2.112  HEAD         POWER LEVEL ACCURACY: [V @LvldBm] dBm @ [V Freq]
  2.113  CALL         Sub MG369XB (2 yr) Pwr Level Test /ML2530
  2.114  ENDIF

  2.115  HEAD
  2.116  CALL         Sub MG369XB Reset & SRQ Masks
  2.117  ML2530       Reset
  2.118  END

  2.119  EVAL   Increment step number

# =====  Sub MG369XB (2 yr) Pwr Level Tests /ML2530,LO  =====================

  3.001  LABEL        PWR_LEVEL_TESTS_ML2530A_LO

  3.002  IF           NOT(@ML2530_LO_RangeCal)
  3.003  HEAD         RANGE CALIBRATION @ [V Freq] MHz
  3.004  TARGET
  3.005  CALL         Sub MG369XB Connection /ML2530
  3.006  CALL         Sub MG369XB ML2530A Relative Range Cal /LO
  3.007  MATH         @ML2530_LO_RangeCal = 1
  3.008  MATH         @RecFreqMHz = ABS(@FreqGHz * 1E+3 - @LoFreqMHz)
  3.009  ENDIF

  3.010  HEAD         DETERMINE OFFSET @ [V Freq]
  3.011  MATH         @LO_Freq = @LoFreqMHz & "MHz"; @LO_Ampl = "+6 dBm"

  3.012  IF           @PS_MinLvl > -60
  3.013  MATH         Range = +20
  3.014  MATH         OffsetLvl = -20
  3.015  MATH         ActualLvl = GET("MG369XB_lvl_-20dBm_" & @FreqGHz)
  3.016  ELSE
  3.017  MATH         Range = -25
  3.018  MATH         OffsetLvl = -50
  3.019  MATH         ActualLvl = GET("MG369XB_lvl_-50dBm_" & @FreqGHz)
  3.020  ENDIF

  3.021  LABEL        OFFSET_ML2530_LO
  3.022  TARGET
  3.023  CALL         Sub MG369XB Connection /ML2530
  3.024  ML2530       NoSensorModuleRequired; Setup
  3.024  ML2530       Bandwidth = 10 Hz; AverageCount = 1
  3.024  ML2530       Freq = [V @RecFreqMHz] MHz; FreqSpan = 10 kHz
  3.024  ML2530       +Level = [V OffsetLvl] dBm; Range = [V Range] dBm
  3.025  CALL         Sub Apply /LO
  3.026  IEEE         CF1[V @FreqGHz]GHL1[V OffsetLvl]DMRF1[D50]
  3.027  ML2530       NoSensorModuleRequired; Read
  3.027  ML2530       Bandwidth = 10 Hz; AverageCount = 1
  3.027  ML2530       Freq = [V @RecFreqMHz] MHz; FreqSpan = 10 kHz
  3.027  ML2530       +Level = [V OffsetLvl] dBm; Range = [V Range] dBm
  3.028  MATH         @Offset = ActualLvl - MEM

# Make sure the computed offset value is reasonable.
  3.029  IF           ABS(@Offset - @MixerConvLossTypicaldB) > 10
  3.030  OPBR         -z |Offset - Mixer Conv. Loss| is greater than 10 dB!
  3.030  OPBR
  3.030  OPBR         Mixer Conversion Loss is [V @MixerConvLossTypicaldB] dB
  3.030  OPBR
  3.030  OPBR         Do you wish to repeat the offset calculation?
  3.031  MATH         Repeat = MEM1

# Initialize connection variable, so connection is displayed.
  3.032  IF           Repeat
  3.033  MATH         @MG369XB_ML2530A_Con = ""
  3.034  ENDIF

  3.035  ELSE
  3.036  MATH         Repeat = 0
  3.037  ENDIF

  3.038  JMPL         OFFSET_ML2530_LO             Repeat

  3.039  IF           @PS_MinLvl > -50
  3.040  MATH         @LvldBm = -25

  3.041  IF           @LvldBm >= Lowest_power_level
  3.042  HEAD         POWER LEVEL ACCURACY: [V @LvldBm] dBm @ [V Freq]
  3.043  CALL         Sub MG369XB (2 yr) Pwr Level Test /ML2530,LO
  3.044  ENDIF

  3.045  MATH         @LvldBm = -30

  3.046  IF           @LvldBm >= Lowest_power_level
  3.047  HEAD         POWER LEVEL ACCURACY: [V @LvldBm] dBm @ [V Freq]
  3.048  CALL         Sub MG369XB (2 yr) Pwr Level Test /ML2530,LO
  3.049  ENDIF

  3.050  MATH         @LvldBm = -35

  3.051  IF           @LvldBm >= Lowest_power_level
  3.052  HEAD         POWER LEVEL ACCURACY: [V @LvldBm] dBm @ [V Freq]
  3.053  CALL         Sub MG369XB (2 yr) Pwr Level Test /ML2530,LO
  3.054  ENDIF

  3.055  MATH         @LvldBm = -40

  3.056  IF           @LvldBm >= Lowest_power_level
  3.057  HEAD         POWER LEVEL ACCURACY: [V @LvldBm] dBm @ [V Freq]
  3.058  CALL         Sub MG369XB (2 yr) Pwr Level Test /ML2530,LO
  3.059  ENDIF

  3.060  MATH         @LvldBm = -45

  3.061  IF           @LvldBm >= Lowest_power_level
  3.062  HEAD         POWER LEVEL ACCURACY: [V @LvldBm] dBm @ [V Freq]
  3.063  CALL         Sub MG369XB (2 yr) Pwr Level Test /ML2530,LO
  3.064  ENDIF

  3.065  MATH         @LvldBm = -50

  3.066  IF           @LvldBm >= Lowest_power_level
  3.067  HEAD         POWER LEVEL ACCURACY: [V @LvldBm] dBm @ [V Freq]
  3.068  CALL         Sub MG369XB (2 yr) Pwr Level Test /ML2530,LO
  3.069  ENDIF

  3.070  ENDIF        ; @PS_MinLvl > -50

  3.071  IF           @PS_MinLvl > -60
  3.072  MATH         @LvldBm = -55

  3.073  IF           @LvldBm >= Lowest_power_level
  3.074  HEAD         POWER LEVEL ACCURACY: [V @LvldBm] dBm @ [V Freq]
  3.075  CALL         Sub MG369XB (2 yr) Pwr Level Test /ML2530,LO
  3.076  ENDIF

  3.077  MATH         @LvldBm = -60

  3.078  IF           @LvldBm >= Lowest_power_level
  3.079  HEAD         POWER LEVEL ACCURACY: [V @LvldBm] dBm @ [V Freq]
  3.080  CALL         Sub MG369XB (2 yr) Pwr Level Test /ML2530,LO
  3.081  ENDIF

  3.082  ENDIF        ; @PS_MinLvl > -60

  3.083  MATH         @LvldBm = -65

  3.084  IF           @LvldBm >= Lowest_power_level
  3.085  HEAD         POWER LEVEL ACCURACY: [V @LvldBm] dBm @ [V Freq]
  3.086  CALL         Sub MG369XB (2 yr) Pwr Level Test /ML2530,LO
  3.087  ENDIF

  3.088  MATH         @LvldBm = -70

  3.089  IF           @LvldBm >= Lowest_power_level
  3.090  HEAD         POWER LEVEL ACCURACY: [V @LvldBm] dBm @ [V Freq]
  3.091  CALL         Sub MG369XB (2 yr) Pwr Level Test /ML2530,LO
  3.092  ENDIF

  3.093  MATH         @LvldBm = -75

  3.094  IF           @LvldBm >= Lowest_power_level
  3.095  HEAD         POWER LEVEL ACCURACY: [V @LvldBm] dBm @ [V Freq]
  3.096  CALL         Sub MG369XB (2 yr) Pwr Level Test /ML2530,LO
  3.097  ENDIF

  3.098  MATH         @LvldBm = -80

  3.099  IF           @LvldBm >= Lowest_power_level
  3.100  HEAD         POWER LEVEL ACCURACY: [V @LvldBm] dBm @ [V Freq]
  3.101  CALL         Sub MG369XB (2 yr) Pwr Level Test /ML2530,LO
  3.102  ENDIF

  3.103  MATH         @LvldBm = -85

  3.104  IF           @LvldBm >= Lowest_power_level
  3.105  HEAD         POWER LEVEL ACCURACY: [V @LvldBm] dBm @ [V Freq]
  3.106  CALL         Sub MG369XB (2 yr) Pwr Level Test /ML2530,LO
  3.107  ENDIF

  3.108  MATH         @LvldBm = -90

  3.109  IF           @LvldBm >= Lowest_power_level
  3.110  HEAD         POWER LEVEL ACCURACY: [V @LvldBm] dBm @ [V Freq]
  3.111  CALL         Sub MG369XB (2 yr) Pwr Level Test /ML2530,LO
  3.112  ENDIF

  3.113  MATH         @LvldBm = -95

  3.114  IF           @LvldBm >= Lowest_power_level
  3.115  HEAD         POWER LEVEL ACCURACY: [V @LvldBm] dBm @ [V Freq]
  3.116  CALL         Sub MG369XB (2 yr) Pwr Level Test /ML2530,LO
  3.117  ENDIF

  3.118  MATH         @LvldBm = -100

  3.119  IF           @LvldBm >= Lowest_power_level
  3.120  HEAD         POWER LEVEL ACCURACY: [V @LvldBm] dBm @ [V Freq]
  3.121  CALL         Sub MG369XB (2 yr) Pwr Level Test /ML2530,LO
  3.122  ENDIF

  3.123  HEAD
  3.124  CALL         Sub MG369XB Reset & SRQ Masks
  3.125  CALL         Sub Reset /LO
  3.126  ML2530       Reset
  3.127  END
